DbParamStyle enum

SQL parameter placeholder style used by each driver.

Inheritance
Available extensions

Values

named → const DbParamStyle

Named @param placeholders — PostgreSQL.

colon → const DbParamStyle

Named :param placeholders — MySQL.

positional → const DbParamStyle

Positional ? placeholders — SQLite.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DbParamStyle>
A constant List of the values in this enum, in order of their declaration.