QueryException class

Any other failed statement — SQL syntax errors, unknown columns, type mismatches, etc.

Inheritance

Constructors

QueryException(String message, {Object? cause})
const

Properties

cause → Object?
The underlying driver exception, when available.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
Human-readable description of what failed.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited