ph method
Returns the placeholder string for key based on paramStyle.
@key for DbParamStyle.named (PostgreSQL),
:key for DbParamStyle.colon (MySQL).
Implementation
String ph(String key) => paramStyle == DbParamStyle.colon ? ':$key' : '@$key';
Returns the placeholder string for key based on paramStyle.
@key for DbParamStyle.named (PostgreSQL),
:key for DbParamStyle.colon (MySQL).
String ph(String key) => paramStyle == DbParamStyle.colon ? ':$key' : '@$key';