insertBatch abstract method
Inserts multiple rows into table in a single batch operation.
All rows must have the same set of keys. Returns a DbResult containing
the inserted rows (PostgreSQL returns them via RETURNING *; other
drivers return an empty rows list with DbResult.affectedRows set).
await db.insertBatch('products', [
{'name': 'Widget', 'price': 9.99},
{'name': 'Gadget', 'price': 19.99},
{'name': 'Doohickey', 'price': 4.99},
]);
Implementation
Future<DbResult> insertBatch(String table, List<Map<String, dynamic>> rows);