insertBatch abstract method
Inserts multiple rows into table in a single batch operation.
All rows must share the same set of keys.
Implementation
Future<DbResult> insertBatch(String table, List<Map<String, dynamic>> rows);
Inserts multiple rows into table in a single batch operation.
All rows must share the same set of keys.
Future<DbResult> insertBatch(String table, List<Map<String, dynamic>> rows);