DbConfig class

Constructors

DbConfig({required DbType type, required String host, required int port, required String database, required String username, required String password, PoolConfig? poolConfig})
const
DbConfig.sqlite(String databasePath)
Convenience constructor for SQLite databases.
const

Properties

database String
final
hashCode int
The hash code for this object.
no setterinherited
host String
final
password String
final
poolConfig PoolConfig?
Optional pool configuration. When null, drivers use PoolConfig defaults.
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DbType
final
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited